import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:slick/configuration/slick_configuration.dart';

class GenericSlickDropDown<T> extends StatelessWidget {
  GenericSlickDropDown({
    Key key,
    @required this.labelText,
    this.initialSelection,
    this.items,
    @required this.onChanged,
    this.validator,
    this.optionTitles,
  }) : super(key: key);

  final List<T> items;
  final T initialSelection;
  final String labelText;
  final ValueChanged<T> onChanged;
  final Function validator;
  final List<String> optionTitles;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 250,
      margin: const EdgeInsets.only(
        top: 3.0,
        right: 8.0,
      ),
      alignment: Alignment.center,
      child: DropdownButtonFormField<T>(
        items: buildItemList(),
        value: initialSelection,
        onChanged: onChanged,
        validator: validator,
        isExpanded: true,
        decoration: InputDecoration(
          contentPadding: EdgeInsets.only(top: 25, bottom: 10),
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          labelText: labelText.toUpperCase(),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          hintText: 'Select a ${labelText.toUpperCase()}',
          hintStyle: GoogleFonts.barlow(
            fontSize: 15,
            color: SlickConfiguration.colors.hintText,
            height: 1.0,
          ),
          labelStyle: GoogleFonts.barlow(
              fontSize: 18,
              fontWeight: FontWeight.w600,
              color: SlickConfiguration.colors.inputLabel,
              height: 0.5),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
        ),
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
          height: 1.0,
        ),
      ),
    );
  }

  List<DropdownMenuItem<T>> buildItemList() {
    var itemList = <DropdownMenuItem<T>>[];
    for (var i = 0; i < items.length; i++) {
      itemList.add(DropdownMenuItem<T>(
        child:
            Text(optionTitles == null ? items[i].toString() : optionTitles[i]),
        value: items[i],
      ));
    }
    return itemList;
  }
}
