import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:slick/configuration/slick_configuration.dart';

class SlickTextInput extends StatelessWidget {
  SlickTextInput({
    Key key,
    @required this.initialValue,
    @required this.onChanged,
    this.labelText,
    this.validator,
    this.obscureText = false,
    this.numberOfLines = 1,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.readOnly = false,
    this.suffix,
    this.prefix,
  }) : super(key: key);

  final String initialValue;
  final String labelText;
  final ValueChanged<String> onChanged;
  final FormFieldValidator<String> validator;
  final bool obscureText;
  final int numberOfLines;
  final EdgeInsetsGeometry padding;
  final double width;
  final bool readOnly;
  final Widget suffix;
  final Widget prefix;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      alignment: Alignment.center,
      child: TextFormField(
        initialValue: initialValue,
        obscureText: obscureText,
        readOnly: readOnly,
        obscuringCharacter: '*',
        onChanged: onChanged,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.hintText,
          ),
          hintText: labelText != null
              ? readOnly
                  ? ' '
                  : labelText.toUpperCase()
              : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: readOnly
                ? Colors.grey.shade700
                : SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        validator: validator,
        maxLines: numberOfLines,
      ),
    );
  }
}
